Index: doc/options.txt
===================================================================
--- doc/options.txt	(revision 4105)
+++ doc/options.txt	(working copy)
@@ -507,11 +507,9 @@
 === Miscellaneous options ===
 
 ;--max-jobs[=integer]
-: 	When number is specified, allow that number of maps to be
-processed concurrently. If number is not specified, the limit
-is set equal to the number of CPU cores. If this option is not
-given at all, the limit is 1 (i.e., the maps are processed
-sequentially).
+: 	Specify the number of threads to be used for concurrent processing.
+If no value is specified, or the option is not given at all, the limit
+is set to the number of CPU cores.
 <p>
 ;--keep-going
 : 	Don't quit whole application if an exception occurs while
Index: resources/help/en/options
===================================================================
--- resources/help/en/options	(revision 4105)
+++ resources/help/en/options	(working copy)
@@ -499,11 +499,9 @@
 Miscellaneous options:
 
 --max-jobs[=integer]
-	When number is specified, allow that number of maps to be
-	processed concurrently. If number is not specified, the limit
-	is set equal to the number of CPU cores. If this option is not
-	given at all, the limit is 1 (i.e., the maps are processed
-	sequentially).
+	Specify the number of threads to be used for concurrent processing.
+	If no value is specified, or the option is not given at all, the limit
+	is set to the number of CPU cores.
 
 --keep-going
 	Don't quit whole application if an exception occurs while
Index: src/uk/me/parabola/mkgmap/main/Main.java
===================================================================
--- src/uk/me/parabola/mkgmap/main/Main.java	(revision 4104)
+++ src/uk/me/parabola/mkgmap/main/Main.java	(working copy)
@@ -19,6 +19,7 @@
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.PrintStream;
+import java.lang.OutOfMemoryError;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
@@ -85,7 +86,7 @@
 	private final List<FilenameTask> futures = new LinkedList<>();
 	private ExecutorService threadPool;
 	// default number of threads
-	private int maxJobs = 1;
+	private static int maxJobs = Runtime.getRuntime().availableProcessors();
 
 	private boolean createTdbFiles = false;
 	private boolean tdbBuilderAdded = false;
@@ -134,6 +135,13 @@
 			CommandArgsReader commandArgs = new CommandArgsReader(mm);
 			commandArgs.setValidOptions(getValidOptions(System.err));
 			commandArgs.readArgs(args);
+		} catch (OutOfMemoryError e) {
+			++numExitExceptions;
+			System.err.println(e);
+			if (maxJobs > 1)
+				System.err.println("Try using the mkgmap --max-jobs option with a value less than " + maxJobs + " to reduce the memory requirement, or use the Java -Xmx option to increase the available heap memory.");
+			else
+				System.err.println("Try using the Java -Xmx option to increase the available heap memory.");
 		} catch (MapFailedException e) {
 			// one of the combiners failed
 			e.printStackTrace();
@@ -503,6 +511,8 @@
 						else
 							throw e;
 					}
+				} catch (OutOfMemoryError me) {
+					throw me;
 				} catch (ExitException ee) {
 					throw ee;
 				} catch (MapFailedException mfe) {
